@@ -34,6 +34,7 @@
 #include "vteptyinternal.hh"
 #include "vtetypes.hh"
 #include "vtespawn.hh"
+#include "reaper.hh"
 
 #include <assert.h>
 #include <sys/types.h>
@@ -74,7 +75,7 @@
 
 #include "glib-glue.hh"
 
-#ifdef __linux__
+#ifdef WITH_SYSTEMD
 #include "systemd.hh"
 #endif
 
@@ -396,7 +397,7 @@ Pty::spawn(char const* directory,
         int i;
         GPollFD pollfd;
 
-#ifndef __linux__
+#ifndef WITH_SYSTEMD
         if (spawn_flags & VTE_SPAWN_REQUIRE_SYSTEMD_SCOPE) {
                 g_set_error(error, G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED,
                             "systemd not available");
@@ -480,7 +481,7 @@ Pty::spawn(char const* directory,
         if (cancellable)
                 g_cancellable_release_fd(cancellable);
 
-#ifdef __linux__
+#ifdef WITH_SYSTEMD
         if (ret &&
             !(spawn_flags & VTE_SPAWN_NO_SYSTEMD_SCOPE) &&
             !vte::systemd::create_scope_for_pid_sync(pid,
@@ -488,6 +489,8 @@ Pty::spawn(char const* directory,
                                                      cancellable,
                                                      err)) {
                 if (spawn_flags & VTE_SPAWN_REQUIRE_SYSTEMD_SCOPE) {
+			vte_reaper_add_child(pid);
+
                         auto pgrp = getpgid(pid);
                         if (pgrp != -1) {
                                 kill(-pgrp, SIGHUP);
@@ -497,10 +500,13 @@ Pty::spawn(char const* directory,
 
                         ret = false;
                 } else {
+                        _vte_debug_print(VTE_DEBUG_PTY,
+                                         "Failed to create systemd scope: %s",
+                                         err.message());
                         err.reset();
                 }
         }
-#endif // __linux__
+#endif // WITH_SYSTEMD
 
         if (!ret)
                 return err.propagate(error);
